commands

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2024 License: Apache-2.0 Imports: 11 Imported by: 0

README

UCM Commands

Command: list

Displays list of named config sets.

> ucm list
Universal Configs Manager:
  - personal
  - work     <= current

Command: show

Displays configuration values of a name config set or from a requested file.

Parameters
  • -n, --name — name of a known configurations set.
  • -f: -file — path or an URL to a file with config values
Examples of usage:
> ucm show --n personal
> ucm show --name work
> ucm show --file ~/.my-config-value.yaml
> ucm show --f https://example.com/some-config.yaml

Command: use

Switches configuration values using a named configs set or values from a file.

Parameters
  • -n, --name — name of a known configurations set.
  • -f: -file — path or an URL to a file with config values
Examples of usage:
> ucm use --n personal
> ucm use --name work
> ucm use --file ~/.my-config-value.yaml
> ucm use --f https://example.com/some-config.yaml

Documentation

Index

Constants

This section is empty.

Variables

var Parser = flags.NewParser(&options, flags.Default)

Parser holds list of commands and provide a method to parse CLI arguments

Functions

This section is empty.

Types

type Options

type Options struct {
	Verbose bool `short:"v" long:"verbose" description:"Verbose output"`
}

Options define & holds common additional arguments for the UCM application

Jump to